@@ -17,7 +17,7 @@
 #'
 #' If \code{sims} is named, or longer than one element, a fan-out strategy is created and used instead.
 #'
-#' If the \code{future} package is installed, you can set  \code{\link[future]{plan}} to run multiple simulations at once.
+#' If the packages \code{future} and \code{future.apply} are installed, you can set \code{\link[future]{plan}} to run multiple simulations in parallel.
 #'
 #'
 #' @examples
@@ -162,6 +162,10 @@ diagnose_design <- function(...,
   structure(out, class = "diagnosis")
 }
 
+#' @rdname diagnose_design
+#' @export
+diagnose_designs <- diagnose_design
+
 reorder_columns <- function(a, b, n1 = colnames(a), n2 = colnames(b))
   c(n1, setdiff(n2, n1))
 
@@ -182,7 +186,7 @@ setup_diagnosands <- function(..., diagnosands) {
 calculate_diagnosands <- function(simulations_df, diagnosands, group_by_set) {
   if ("design_label" %in% group_by_set) {
     group_by_list <- simulations_df[, "design_label", drop = FALSE]
-    labels_df <- split(group_by_list, group_by_list, drop = TRUE)
+    labels_df <- split(group_by_list, lapply(group_by_list, addNA), drop = TRUE)
     labels_df <- lapply(labels_df, head, n = 1)
 
     # ensure diagnosand functions are in the same order as designs
@@ -192,7 +196,7 @@ calculate_diagnosands <- function(simulations_df, diagnosands, group_by_set) {
       diagnosands <- diagnosands[names(labels_df)]
     }
 
-    simulations_list <- split(simulations_df, group_by_list, drop = TRUE)
+    simulations_list <- split(simulations_df, lapply(group_by_list, addNA), drop = TRUE)
 
     if (is.list(diagnosands)) {
       diagnosands_df <- mapply(calculate_diagnosands_single_design, simulations_list, diagnosands,
@@ -220,11 +224,11 @@ calculate_diagnosands <- function(simulations_df, diagnosands, group_by_set) {
 
 calculate_diagnosands_single_design <- function(simulations_df, diagnosands, group_by_set) {
   group_by_list <- simulations_df[, group_by_set, drop = FALSE]
-
-  labels_df <- split(group_by_list, group_by_list, drop = TRUE)
+  
+  labels_df <- split(group_by_list, lapply(group_by_list, addNA), drop = TRUE)
   labels_df <- lapply(labels_df, head, n = 1)
 
-  diagnosands_df <- split(simulations_df, group_by_list, drop = TRUE)
+  diagnosands_df <- split(simulations_df, lapply(group_by_list, addNA), drop = TRUE)
   diagnosands_df <- lapply(diagnosands_df, FUN = function(x) {
     dg <- diagnosands(x)
     setNames(dg[[2]], dg[[1]])
@@ -240,11 +244,11 @@ calculate_diagnosands_single_design <- function(simulations_df, diagnosands, gro
 
 calculate_sims <- function(simulations_df, group_by_set) {
   group_by_list <- simulations_df[, group_by_set, drop = FALSE]
-
-  labels_df <- split(group_by_list, group_by_list, drop = TRUE)
+  
+  labels_df <- split(group_by_list, lapply(group_by_list, addNA), drop = TRUE)
   labels_df <- lapply(labels_df, head, n = 1)
 
-  n_sims_df <- split(simulations_df, group_by_list, drop = TRUE)
+  n_sims_df <- split(simulations_df, lapply(group_by_list, addNA), drop = TRUE)
   n_sims_df <- lapply(n_sims_df, FUN = function(x) {
     data.frame(n_sims = nrow(x))
   })
@@ -258,7 +262,7 @@ calculate_sims <- function(simulations_df, group_by_set) {
 
 
 bootstrap_diagnosands <- function(bootstrap_sims, simulations_df, diagnosands, diagnosands_df, group_by_set) {
-  bootstrap_level <- if ("fan_1" %in% names(simulations_df)) "fan_1" else "sim_ID"
+  bootstrap_level <- if ("step_1_draw" %in% names(simulations_df)) "step_1_draw" else "sim_ID"
 
   boot_indicies_by_id <- split(seq_len(nrow(simulations_df)), simulations_df[, bootstrap_level])
   nsims <- max(simulations_df[, bootstrap_level])
@@ -286,19 +290,19 @@ bootstrap_diagnosands <- function(bootstrap_sims, simulations_df, diagnosands, d
 
   # Prep for se calculation
   group_by_list <- diagnosand_replicates[, group_by_set, drop = FALSE]
-  labels_df <- split(group_by_list, group_by_list, drop = TRUE)
+  labels_df <- split(group_by_list, lapply(group_by_list, addNA), drop = TRUE)
   labels_df <- lapply(labels_df, head, n = 1)
 
   diagnosands_df_group <- diagnosands_df[, group_by_set, drop = FALSE]
   diagnosands_df[group_by_set] <- NULL
   diagnosands_names <- colnames(diagnosands_df)
 
-  diagnosands_df <- split(diagnosands_df, diagnosands_df_group, drop = TRUE)
+  diagnosands_df <- split(diagnosands_df, lapply(diagnosands_df_group, addNA), drop = TRUE)
   diagnosands_df <- diagnosands_df[names(labels_df)]
 
   # Calculate standard errors
   use_vars <- setdiff(names(diagnosand_replicates), c(group_by_set, "bootstrap_id"))
-  diagnosands_se_df <- split(diagnosand_replicates[use_vars], group_by_list, drop = TRUE)
+  diagnosands_se_df <- split(diagnosand_replicates[use_vars], lapply(group_by_list, addNA), drop = TRUE)
   diagnosands_se_df <- lapply(diagnosands_se_df, lapply, sd)
 
   # Clean up
