@@ -180,7 +180,7 @@ test_that("custom tidy method", {
   
   des <- pop + declare_estimator(model = model_function)
   
-  expect_error(draw_estimates(des), "The default tidy method")
+  expect_error(draw_estimates(des), "We were unable to tidy the output")
 
   tidy.my_modelr <- function(fit, conf.int = TRUE){
     return(data.frame(term = "my-term", est = 1))
@@ -243,9 +243,13 @@ test_that("gam", {
   des <- pop + declare_estimator(Y ~ Z, model = gam::gam)
   if(packageVersion("broom") <= "0.5.0") {
     expect_error(draw_estimates(des))
-  } else {
+  } else if(packageVersion("gam") < "1.16") {
     expect_warning(expect_equal(ncol(draw_estimates(des)), 7))
+  } else {
+    expect_equal(ncol(draw_estimates(des)), 7)
   }
+  
+  
 })
 
 test_that("lfe", {
@@ -261,3 +265,5 @@ test_that("polr", {
   suppressWarnings(expect_error(draw_estimates(des)))
 })
 
+
+
